/***************************************************************************
    copyright            : (C) 2001-2008 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#include "mainwindow.h"
#include "translators/translators.h" // needed for file type enum

#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>

namespace {
  static const char* description = "Tellico - a collection manager for KDE";
  static const char* version = VERSION;
}

int main(int argc, char* argv[]) {
  KAboutData aboutData("tellico", 0, ki18n("Tellico"),
                       version, ki18n(description), KAboutData::License_GPL,
                       ki18n("(c) 2001-%1, Robby Stephenson").subs(2008), KLocalizedString(),
                       "http://www.periapsis.org/tellico/", "tellico-users@forge.novell.com");
  aboutData.addAuthor(ki18n("Robby Stephenson"), KLocalizedString(), "robby@periapsis.org");
  aboutData.addAuthor(ki18n("Mathias Monnerville"), ki18n("Data source scripts"));
  aboutData.addAuthor(ki18n("Regis Boudin"), KLocalizedString());
  aboutData.addAuthor(ki18n("Petri Damstén"), KLocalizedString(), "damu@iki.fi");

  aboutData.addCredit(ki18n("Virginie Quesnay"), ki18n("Icons"));
  aboutData.addCredit(ki18n("Amarok"), ki18n("Code examples and general inspiration"),
                      QByteArray(), "http://amarok.kde.org");
  aboutData.addCredit(ki18n("Greg Ward"), ki18n("Author of btparse library"));
  aboutData.addCredit(ki18n("Robert Gamble"), ki18n("Author of libcsv library"));
  aboutData.addCredit(ki18n("Valentin Lavrinenko"), ki18n("Author of rtf2html library"));

  KCmdLineOptions options;
  options.add("nofile", ki18n("Do not reopen the last open file"));
  options.add("bibtex", ki18n("Import <filename> as a bibtex file"));
  options.add("mods", ki18n("Import <filename> as a MODS file"));
  options.add("ris", ki18n("Import <filename> as a RIS file"));
  options.add("+[filename]", ki18n("File to open"));

  KCmdLineArgs::init(argc, argv, &aboutData);
  KCmdLineArgs::addCmdLineOptions(options);

  KApplication app;

  if(app.isSessionRestored()) {
    RESTORE(Tellico::MainWindow);
  } else {
    Tellico::MainWindow* tellico = new Tellico::MainWindow();
    tellico->show();
    tellico->slotShowTipOfDay(false);

    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
    if(args->count() > 0) {
      if(args->isSet("bibtex")) {
        tellico->importFile(Tellico::Import::Bibtex, args->url(0), Tellico::Import::Replace);
      } else if(args->isSet("mods")) {
        tellico->importFile(Tellico::Import::MODS, args->url(0), Tellico::Import::Replace);
      } else if(args->isSet("ris")) {
        tellico->importFile(Tellico::Import::RIS, args->url(0), Tellico::Import::Replace);
      } else {
        tellico->slotFileOpen(args->url(0));
      }
    } else {
      // bit of a hack, I just want the --nofile option
      // if --nofile is NOT passed, then the file option is set
      // is it's set, then go ahead and check for opening previous file
      tellico->initFileOpen(!args->isSet("file"));
    }
    args->clear(); // some memory savings
  }

  return app.exec();
}
